summaryrefslogtreecommitdiff
path: root/src/reflowscan.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/reflowscan.cpp')
-rw-r--r--src/reflowscan.cpp5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/reflowscan.cpp b/src/reflowscan.cpp
index 49b9406d7..eec371022 100644
--- a/src/reflowscan.cpp
+++ b/src/reflowscan.cpp
@@ -22,12 +22,13 @@ with this program; if not, write to the Free Software Foundation, Inc.,
#include "mapblock.h"
#include "nodedef.h"
#include "util/timetaker.h"
+#include "util/cpp11.h"
ReflowScan::ReflowScan(Map *map, INodeDefManager *ndef) :
m_map(map),
m_ndef(ndef),
- m_liquid_queue(NULL)
+ m_liquid_queue(nullptr)
{
}
@@ -41,7 +42,7 @@ void ReflowScan::scan(MapBlock *block, UniqueQueue<v3s16> *liquid_queue)
// scanned block. Blocks are only added to the lookup if they are really
// needed. The lookup is indexed manually to use the same index in a
// bit-array (of uint32 type) which stores for unloaded blocks that they
// were already fetched from Map but were actually NULL.
memset(m_lookup, 0, sizeof(m_lookup));
int block_idx = 1 + (1 * 9) + (1 * 3);
m_lookup[block_idx] = block;
@@ -41,7 +42,7 @@ void ReflowScan::scan(MapBlock *block, UniqueQueue<v3s16> *liquid_queue)
// needed. The lookup is indexed manually to use the same index in a
// bit-array (of uint32 type) which stores for unloaded blocks that they
- // were already fetched from Map but were actually NULL.
+ // were already fetched from Map but were actually nullptr.
memset(m_lookup, 0, sizeof(m_lookup));
int block_idx = 1 + (1 * 9) + (1 * 3);